@@ -80,34 +80,25 @@ void account_locked_checkbutton_clicked(struct w *widgets)
 {
     FILE *fp;
     int locked = 0;
-    int exists = 0;
     int have_password = 0;
     gchar *info, *cmd;
     G_CONST_RETURN gchar *username, *password;
 
-    username  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[0]));
-    password  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[1]));
+    username = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[0]));
+    password = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[1]));
 
     if( password!=NULL && strlen(password) >= atoi(MIN_PASS_LEN) )
       have_password = 1;
 
-    exists = smbuser_exists(username);
-    if( ! exists )
+    if( ! smbuser_exists(username) )
     {
 	info = g_strdup_printf(_("Can not lock or unlock a samba user that does not exist.\n"));
 	show_info(info);
 	g_free(info);
-        /* Set account locked checkbutton [x] if its still locked */
-        // FIXME: treats users with NULL passwords as locked.
-        if( locked )
-	  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0]), TRUE);
-	else
-	  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0]), FALSE);
-
 	return;    
     }
 
-    /* Get the samba accounts lock state from the smbpasswd file */
+    /* Get the samba accounts lock state */
     locked = smbuser_locked(username);
 
     /* Sanitycheck. Not required anymore */
@@ -127,10 +118,10 @@ void account_locked_checkbutton_clicked(struct w *widgets)
 	return;    
     }
 
-    /* Disable an existing samba account if thats selected */
+    /* Disable an existing samba account if selected */
     if( ! locked && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0])) )
     {
-	cmd = g_strdup_printf("%s -d '%s'", SMBPASSWD_BINARY, username);
+	cmd = g_strdup_printf("%s -c \"[D ]\" -u '%s'", PDBEDIT_BINARY, username);
 	if((fp=popen(cmd, "w"))==NULL)
 	{
 	    perror("popen");
@@ -158,7 +149,7 @@ void account_locked_checkbutton_clicked(struct w *widgets)
 	   beeing disabled so just enable the account */
 	if( ! have_password && locked == 1 )
 	{
-	    cmd = g_strdup_printf("%s -e '%s'", SMBPASSWD_BINARY, username);
+	    cmd = g_strdup_printf("%s -c \"[ ]\" -u '%s'", PDBEDIT_BINARY, username);
 	    if((fp=popen(cmd, "w"))==NULL)
 	    {
 		perror("popen");
@@ -179,7 +170,7 @@ void account_locked_checkbutton_clicked(struct w *widgets)
 	/* The user had no password before beeing locked or has a NULL password so require a new password */
 	if( (have_password) && (locked == 1 || locked == 2 || locked == 3) ) 
 	{
-	    cmd = g_strdup_printf("%s -s -a -e '%s'", SMBPASSWD_BINARY, username);
+	    cmd = g_strdup_printf("%s -t -a -u '%s'", PDBEDIT_BINARY, username);
 	    if((fp=popen(cmd, "w"))==NULL)
 	    {
 	        perror("popen");
@@ -250,9 +241,22 @@ void add_change_user(struct w *widgets)
     /* Its a gtk combo box entry new text */
     shell     = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(widgets->user_set_combo[0])->child));
 
-    /* The smbpasswd file is sometimes missing from rpm installs etc so attempt to
-       create it if its missing before adding or changing any users */
-    path = g_strdup_printf("%s", SAMBA_PASSWD);
+
+    /* Puts the pdbedit userlist as:
+       /etc/gadmin-samba/gadmin_samba_users */
+    get_gadmin_samba_users();
+
+
+    if( ! smbuser_exists(username)
+    &&  ( password == NULL || strlen(password) < atoi(MIN_PASS_LEN) ))
+    {
+	info = g_strdup_printf(_("You must specify a valid password for this new user.\n"));
+	show_info(info);
+	g_free(info);
+	return;	
+    }
+
+    path = g_strdup_printf("%s", GADMIN_SAMBA_USERS);
     if( ! file_exists(path) )
       make_file_chmod(path, "0600");
 
@@ -305,7 +309,7 @@ void add_change_user(struct w *widgets)
     }
 
     /* Root user specified, only change its samba settings */
-    if( ! strcmp(username, "root") )
+    if( strcmp(username, "root") == 0 )
     {
 	/* If the root system user doesnt exist, tell the user and return. */	
 	if( ! user_exists(username) )
@@ -318,7 +322,7 @@ void add_change_user(struct w *widgets)
 
 	if( password!=NULL && strlen(password) >= atoi(MIN_PASS_LEN) )
 	{
-    	    cmd = g_strdup_printf("%s -s -a '%s'", SMBPASSWD_BINARY, username);
+    	    cmd = g_strdup_printf("%s -t -a -u '%s'", PDBEDIT_BINARY, username);
     	    if((fp=popen(cmd, "w"))==NULL)
     	    {
 		perror("popen");
@@ -401,9 +405,9 @@ void add_change_user(struct w *widgets)
 
 
     /* Add a new samba user with this password or change the old password. */
-    if( password!=NULL && strlen(password) > 0 ) //Users choise is better here >= atoi(MIN_PASS_LEN) )
+    if( password!=NULL && strlen(password) >= atoi(MIN_PASS_LEN) )
     {
-        cmd = g_strdup_printf("%s -s -a '%s'", SMBPASSWD_BINARY, username);
+        cmd = g_strdup_printf("%s -t -a -u '%s'", PDBEDIT_BINARY, username);
         if((fp=popen(cmd, "w"))==NULL)
         {
 	    perror("popen");
@@ -419,15 +423,11 @@ void add_change_user(struct w *widgets)
 	fputs("\n", fp);
 	pclose(fp);
 	g_free(cmd);
+
+	/* Also change the system accounts password. */
+	password_user(username, password);
     }
-    /* The user has typed a password but its not long enough. See users choise above^ */
-//    if( password!=NULL && strlen(password) == 0 ) //Users choise instead && strlen(password) < atoi(MIN_PASS_LEN) )
-//    {
-//	info = g_strdup_printf(_("The password is too short.\nFailed adding or setting password for samba user: %s\n"), username);
-//	show_info(info);
-//	g_free(info);
-//	return;
-//    }
+
 
     /* Change this users system comment */
     cmd = g_strdup_printf("%s -c '%s' '%s'\n", "usermod", comment, username);
