@@ -34,7 +34,6 @@
 #include "select_first_macct.h"
 #include "populate_macct_settings.h"
 #include "commands.h"
-
 #include "system_defines.h"
 
 extern int activated;
@@ -54,14 +53,9 @@ void add_macct(struct w *widgets)
     username  = gtk_entry_get_text(GTK_ENTRY(widgets->macct_set_entry[0]));
     comment   = gtk_entry_get_text(GTK_ENTRY(widgets->macct_set_entry[1]));
 
+    get_gadmin_samba_users();
 
-    printf("Adding machine acct: %s$\n", username);
-    printf("With comment   cmnt: %s\n", comment);
-
-
-    /* The smbpasswd file is sometimes missing from rpm installs etc so
-       attempt to make it before adding or changing any users */
-    path = g_strdup_printf("%s", SAMBA_PASSWD);
+    path = g_strdup_printf("%s", GADMIN_SAMBA_USERS);
     if( ! file_exists(path) )
       make_file_chmod(path, "0600");
 
@@ -134,8 +128,8 @@ void add_macct(struct w *widgets)
     }
     
 
-    /* Add the samba machine account. (No '$' used) */
-    cmd = g_strdup_printf("%s -a -m '%s'", SMBPASSWD_BINARY, username);
+    /* Add the samba machine account. (No '$' or password is used) */
+    cmd = g_strdup_printf("%s -a -m '%s'", PDBEDIT_BINARY, username);
     if((fp=popen(cmd, "w"))==NULL)
     {
 	perror("popen");
