@@ -105,16 +105,6 @@ int add_standard_users()
     }
     g_free(cmd);
 
-    /* SYSCONFDIR/samba/smbpasswd is required */
-    cmd = g_strdup_printf("touch %s/samba/smbpasswd", SYSCONFDIR);
-    if( ! run_command(cmd) )
-    {
-        printf("Error creating directory: %s/samba/smbpasswd\n", SYSCONFDIR);
-        g_free(cmd);
-        return 0;
-    }
-    g_free(cmd);
-
     /* SYSCONFDIR/samba/smb.conf is required */
     cmd = g_strdup_printf("touch %s/samba/smb.conf", SYSCONFDIR);
     if( ! run_command(cmd) )
@@ -125,16 +115,6 @@ int add_standard_users()
     }
     g_free(cmd);
 
-    /* SYSCONFDIR/samba/smbpasswd is required */
-    cmd = g_strdup_printf("touch %s/samba/smbpasswd", SYSCONFDIR);
-    if( ! run_command(cmd) )
-    {
-        printf("Error creating directory: %s/samba/smbpasswd\n", SYSCONFDIR);
-        g_free(cmd);
-        return 0;
-    }
-    g_free(cmd);
-
     /* We want username mappings in /etc/samba/smbusers */
     conf = g_strconcat(
     "# Unix_name = SMB_Name1 SMB_Name2 ...\n",
@@ -239,24 +219,14 @@ int add_standard_users()
     g_free(name);
 
 
-    /* The smbguest user also needs to be added to the smbpasswd file as a locked user */
+    /* The smbguest user also needs to be added to the samba user/pass file as a locked user */
     name = g_strdup_printf("%s", "smbguest");
     if( ! smbuser_exists(name) )
     {
-	/* a=add d=disable */
-	cmd = g_strdup_printf("%s -a -d '%s'\n", SMBPASSWD_BINARY, name);
-	if((fp=popen(cmd, "w"))==NULL)
+	if( ! add_locked_samba_user(name) )
 	{
-    	    perror("popen");
-    	    info = g_strdup_printf(_("Failed adding default samba user: %s\n"), name);
-    	    show_info(info);
-    	    g_free(info);
-    	    g_free(cmd);
-	    g_free(name);
-    	    return 0;
+	    printf("Error adding standard samba user: %s\n", name);
 	}
-	pclose(fp);
-	g_free(cmd);
     }
     g_free(name);
 
@@ -280,24 +250,14 @@ int add_standard_users()
     g_free(name);
 
 
-    /* The samba root user also needs to be added to be able to connect to this domain */
+    /* The samba root user also needs to be added to be able to join this domain */
     name = g_strdup_printf("%s", "root");
     if( ! smbuser_exists(name) )
     {
-	/* a=add d=disable */
-	cmd = g_strdup_printf("%s -a -d '%s'\n", SMBPASSWD_BINARY, name);
-	if((fp=popen(cmd, "w"))==NULL)
+	if( ! add_locked_samba_user(name) )
 	{
-    	    perror("popen");
-    	    info = g_strdup_printf(_("Failed adding default samba user: %s\n"), name);
-    	    show_info(info);
-    	    g_free(info);
-    	    g_free(cmd);
-	    g_free(name);
-    	    return 0;
+	    printf("Error adding standard samba user: %s\n", name);
 	}
-	pclose(fp);
-	g_free(cmd);
     }
     g_free(name);
 
