@@ -65,7 +65,6 @@ void apply_server_settings(struct w *widgets)
     G_CONST_RETURN gchar *printcap_path;
     G_CONST_RETURN gchar *guest_users;
     G_CONST_RETURN gchar *samba_logfile;
-    G_CONST_RETURN gchar *samba_password_file;
     G_CONST_RETURN gchar *samba_password_program;
     G_CONST_RETURN gchar *new_pass_phrase;
     G_CONST_RETURN gchar *samba_username_mapfile;
@@ -195,7 +194,6 @@ void apply_server_settings(struct w *widgets)
     name_resolve_order = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[16]));
     wins_servers = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[17]));
     samba_username_mapfile = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[18]));
-    samba_password_file = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[19]));
     samba_password_program = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[20]));
 //    samba_root_home = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[21]));
     new_pass_phrase = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[22]));
@@ -387,12 +385,6 @@ void apply_server_settings(struct w *widgets)
     	    strcat(new_conf, conf_line);
 	}
 	else
-	if( strstr(line, "smb passwd file") )
-	{
-    	    sprintf(conf_line, "smb passwd file = %s\n", samba_password_file);
-    	    strcat(new_conf, conf_line);
-	}
-	else
 	if( strstr(line, "passwd program") )
 	{
     	    sprintf(conf_line, "passwd program = %s\n", samba_password_program);
