@@ -82,6 +82,7 @@ int run_command(gchar *command)
     return exit_status;
 }
 
+
 void init_start(struct w *widgets)
 {
     gchar *cmd;
@@ -103,6 +104,7 @@ void init_start(struct w *widgets)
       g_free(cmd);
 }
 
+
 void init_stop(struct w *widgets)
 {
     gchar *cmd;
@@ -124,6 +126,7 @@ void init_stop(struct w *widgets)
       g_free(cmd);
 }
 
+
 int file_exists(char *infile)
 {
     FILE *fp;
@@ -135,36 +138,99 @@ int file_exists(char *infile)
 }
 
 
-/* Not used */
-int using_tls(void)
+void get_gadmin_samba_users()
+{
+    gchar *cmd;
+
+    /* Secure the gadmin_samba_users file. */
+    cmd = g_strdup_printf("touch %s && chmod 600 %s\n", GADMIN_SAMBA_USERS, GADMIN_SAMBA_USERS);
+    if( ! run_command(cmd) )
+    {
+	printf("Show info here: Creating an initial gadmin_samba_users file failed.\n");    
+    }
+    g_free(cmd);
+
+    /* List users like the smbpasswd file. (Use -v instead of -w to get more info) */
+    cmd = g_strdup_printf("%s -L -w > %s\n", PDBEDIT_BINARY, GADMIN_SAMBA_USERS);
+    if( ! run_command(cmd) )
+    {
+	printf("Show info here: pbedit -L -w -v failed.\n");    
+    }
+    g_free(cmd);
+}
+
+
+int add_locked_samba_user(gchar *username)
 {
     FILE *fp;
-    int retval = 0;
-    char *buffy;    
+    gchar *info, *cmd;
 
-    /* Dont show TLS options if we dont have the module */
-    if((fp=popen("gadmin-samba -l","r"))==NULL)
+    /* Add the user */
+    cmd = g_strdup_printf("%s -t -a -u '%s'", PDBEDIT_BINARY, username);
+    if((fp=popen(cmd, "w"))==NULL)
     {
-	/* Locale trouble could be one cause so add TLS options */
-	retval = 1;
+	perror("popen");
+	info = g_strdup_printf(_("Failed adding locked samba user: %s\n"), username);
+    	show_info(info);
+    	g_free(info);
+	g_free(cmd);
+	return 0;
     }
-    else
-      {	
-	 buffy = allocate(MAX_READ_POPEN+1);
-	 while(fgets(buffy, MAX_READ_POPEN, fp)!=NULL)
-	 {
-	    if( strstr(buffy, "mod_tls") )
-	    {
-	        retval = 1;
-	        break;
-	    }
-	 }
-	 free(buffy);
-         pclose(fp);
-      }
+    fputs("\n", fp);
+    fputs("\n", fp);
+    pclose(fp);
+    g_free(cmd);
 
-    /* For testing wo ssl widgets use */
-    /* retval = 0;  */
-    
-    return retval;
+    /* Disable it */
+    cmd = g_strdup_printf("%s -c \"[D ]\" -u '%s'", PDBEDIT_BINARY, username);
+    if((fp=popen(cmd, "w"))==NULL)
+    {
+	perror("popen");
+	info = g_strdup_printf(_("Failed disabling/locking samba user: %s\n"), username);
+    	show_info(info);
+    	g_free(info);
+	g_free(cmd);
+	return 0;
+    }
+    pclose(fp);
+    g_free(cmd);
+
+    return 1;
+}
+
+
+int add_null_password_samba_user(gchar *username)
+{
+    FILE *fp;
+    gchar *info, *cmd;
+
+    /* Add the user */
+    cmd = g_strdup_printf("%s -t -a -u '%s'", PDBEDIT_BINARY, username);
+    if((fp=popen(cmd, "w"))==NULL)
+    {
+	perror("popen");
+	info = g_strdup_printf(_("Failed adding null password samba user: %s\n"), username);
+    	show_info(info);
+    	g_free(info);
+	g_free(cmd);
+	return 0;
+    }
+    fputs("\n", fp);
+    fputs("\n", fp);
+    pclose(fp);
+    g_free(cmd);
+
+    /* Set null password / require no password if NULL passwords are allowed */
+    cmd = g_strdup_printf("%s -c \"[N ]\" -u '%s'", PDBEDIT_BINARY, username);
+    if((fp=popen(cmd, "w"))==NULL)
+    {
+	perror("popen");
+	info = g_strdup_printf(_("Failed locking null password samba user: %s\n"), username);
+    	show_info(info);
+    	g_free(info);
+	g_free(cmd);
+	return 0;
+    }
+
+    return 1;
 }
