@@ -20,7 +20,7 @@
 
 
 #ifndef commands_H
-#	define commands_H
+#define commands_H
 
 int run_command(gchar *command);
 void run_command_show_err(gchar *command);
@@ -28,5 +28,8 @@ int file_exists(char *infile);
 int using_tls(void);
 void init_start(struct w *widgets);
 void init_stop(struct w *widgets);
+void get_gadmin_samba_users();
+int add_locked_samba_user(gchar *username);
+int add_null_password_samba_user(gchar *username);
 
 #endif
