@@ -18,11 +18,7 @@
 */
 
 
-
-#ifdef HAVE_CONFIG_H
-#  include "../config.h"
-#endif
-
+#include "../config.h"
 #include <gtk/gtk.h>
 #include "gettext.h"
 #include "support.h"
