@@ -31,12 +31,9 @@
 #include "make_settings_progressbars.h"
 #include "make_settings_labels.h"
 #include "make_settings_hseparators.h"
-//#include "generate_cert.h"
 #include "create_server_settings.h"
 #include "apply_server_settings.h"
 
-//extern int use_tls;
-
 
 
 void create_server_settings(struct w *widgets)
@@ -559,9 +556,8 @@ void create_server_settings(struct w *widgets)
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The path to SAMBA's username file, IE: /etc/samba/smbusers"), NULL);
     a++; b++; ent++;
 
-    /* Samba password file */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" SAMBA password file: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The path to SAMBA's passwd file, IE: /etc/samba/smbpasswd"), NULL);
+    /* DEPRECATED: Samba password file */
+//  Leave these...
     a++; b++; ent++;
 
     /* The systems passwd program */
