@@ -1,5 +1,5 @@
 /* GADMIN-SAMBA, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006, 2007, 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 #include "add_share.h"
 #include "create_import_question.h"
 #include "apply_share_settings.h"
+#include "file_chooser.h"
 #include "show_info.h"
 
 int new_share_info_shown = 0;
@@ -98,7 +99,7 @@ void new_share_clicked(GtkButton *button, struct w *widgets)
 	gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[i]), "");
               
     /* Set all share combos to commonly used settings. */
-    for(i=0; i<9; i++)
+    for(i=0; i<8; i++)
         gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->share_set_combo[i]), 1);
 
     /* Set combo 1 and 2 to yes. (Available and browseable) */
@@ -190,6 +191,20 @@ void del_share_access_clicked(GtkButton *button, struct w *widgets)
 }
 
 
+void select_share_path_clicked(struct w *widgets)
+{
+    gchar *path = NULL;
+
+    path = get_dialog_path_selection("DIR", "/var/samba", "None");
+    if( path!=NULL )
+    {
+        printf("Selected directory: %s\n", path);
+        gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[1]), path);
+        g_free(path);
+    }
+}
+
+
 void create_share_settings(struct w *widgets)
 {
     GtkTooltips *tooltips;
@@ -283,6 +298,11 @@ void create_share_settings(struct w *widgets)
                                              0,1,a,b,350);
     a++; b++; ent++;
 
+    g_signal_connect_swapped(G_OBJECT(sharepath_button), "clicked",
+			     G_CALLBACK(select_share_path_clicked), widgets);
+
+
+
 
     /* A comment */
     widgets->share_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->share_set_table), _(" Comment: "), 0,1,a,b,350);
@@ -593,7 +613,7 @@ void create_share_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* share modes combo */
+/*  "share modes" Has been deprecated.
     widgets->share_set_combo[comb] = make_label_combo_label(GTK_TABLE(widgets->share_set_table), _(" Share modes: "), 0,1,a,b, 80);
     combo_text = g_strdup_printf(_("Yes"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
@@ -603,6 +623,7 @@ void create_share_settings(struct w *widgets)
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->share_set_combo[comb]), utf8);
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
+*/
 
     /* locking combo */
     widgets->share_set_combo[comb] = make_label_combo_label(GTK_TABLE(widgets->share_set_table), _(" File locking: "), 0,1,a,b, 80);
@@ -615,5 +636,16 @@ void create_share_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
+    /* Strict locking */
+    widgets->share_set_combo[comb] = make_label_combo_label(GTK_TABLE(widgets->share_set_table), _(" Strict locking: "), 0,1,a,b, 80);
+    combo_text = g_strdup_printf(_("Yes"));
+    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->share_set_combo[comb]), utf8);
+    combo_text = g_strdup_printf(_("No"));
+    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->share_set_combo[comb]), utf8);
+    g_free(combo_text); g_free(utf8);
+    a++; b++; comb++;
+
     gtk_widget_show_all(widgets->main_window);
 }
