@@ -37,6 +37,8 @@
 #include "functions.h"
 #include "file_chooser.h"
 
+gulong account_disabled_toggled_signal;
+
 
 
 void select_home_path_clicked(struct w *widgets)
@@ -55,7 +57,6 @@ void select_home_path_clicked(struct w *widgets)
 void create_user_settings(struct w *widgets)
 {
     GtkTooltips *tooltips;
-//    gchar *utf8 = NULL;
     GtkWidget *hbuttonbox;
     GtkWidget *delete_user_button;
     GtkWidget *apply_user_button;
@@ -89,10 +90,10 @@ void create_user_settings(struct w *widgets)
     gtk_container_add(GTK_CONTAINER(new_user_alignment), new_user_hbox);
     new_user_image = gtk_image_new_from_stock("gtk-add", GTK_ICON_SIZE_BUTTON);
 
-    gtk_box_pack_start(GTK_BOX(new_user_hbox), new_user_image, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(new_user_hbox), new_user_image, TRUE, TRUE, 0);
     new_user_label = gtk_label_new_with_mnemonic(_("New user"));
 
-    gtk_box_pack_start(GTK_BOX(new_user_hbox), new_user_label, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(new_user_hbox), new_user_label, TRUE, TRUE, 0);
     gtk_label_set_justify(GTK_LABEL(new_user_label), GTK_JUSTIFY_LEFT);
     /* Custom new user button end */
 
@@ -122,10 +123,10 @@ void create_user_settings(struct w *widgets)
     g_signal_connect_swapped(G_OBJECT(new_user_button), "clicked",
 			     G_CALLBACK(clear_user_profile), widgets);
 
-    g_signal_connect_swapped(G_OBJECT(widgets->user_set_checkbutton[0]), "clicked",
-			     G_CALLBACK(account_locked_checkbutton_clicked), widgets);
-			     
-//    gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox), GTK_BUTTONBOX_SPREAD);
+
+    /* Fetch the gulong as well as hooking up the connect signal. Borked like this in 2006 ? */
+    account_disabled_toggled_signal = g_signal_connect_swapped(G_OBJECT(widgets->user_set_checkbutton[0]),
+				    "clicked", G_CALLBACK(account_locked_checkbutton_clicked), widgets);
 
 
     /* Username */	     /* Max length and input 350 chars */
