@@ -56,7 +56,7 @@ void delete_macct(struct w *widgets)
     machine_acct = g_strdup_printf("%s$", username);
 
     /* Delete the samba machine account if it exists. */
-    cmd = g_strdup_printf("%s -x '%s'", SMBPASSWD_BINARY, machine_acct);
+    cmd = g_strdup_printf("%s -x '%s'", PDBEDIT_BINARY, machine_acct);
     if((fp=popen(cmd, "w"))==NULL)
     {
 	perror("popen");
