@@ -184,18 +184,6 @@ void delete_user(struct w *widgets)
     fclose(fp);
     free(new_conf);
 
-    /* Delete the samba user */
-    cmd = g_strdup_printf("%s -x %s", SMBPASSWD_BINARY, username);
-    if( ! run_command(cmd) )
-    {
-        info = g_strdup_printf(_("Could not remove the samba user: %s\n"), username);
-        show_info(info);
-	g_free(info);
-	/* Dont return.. just tell the user */
-    }
-    g_free(cmd);
-
-
     /* Dont ever ask to delete the root system user */
     if( username[0]=='r' && username[1]=='o' 
     &&  username[2]=='o' && username[3]=='t' && strlen(username)==4 ) 
@@ -206,6 +194,22 @@ void delete_user(struct w *widgets)
 	root_user = 1;
     }
 
+    
+    /* Delete the samba user */
+    if( ! root_user )
+    {
+	cmd = g_strdup_printf("%s -x -u '%s'", PDBEDIT_BINARY, username);
+	if( ! run_command(cmd) )
+	{
+    	    info = g_strdup_printf(_("Could not remove the samba user: %s\n"), username);
+    	    show_info(info);
+	    g_free(info);
+	    /* Dont return.. just tell the user */
+	}
+	g_free(cmd);
+    }
+
+
     /* Ask to delete the system user if its not "root" */
     if( user_exists(username) && ! root_user )
     {
