@@ -277,8 +277,12 @@ smbuser_exists(G_CONST_RETURN gchar *username)
     int x, user_exists = 0;
     char tempname[4096]="";
 
-    /* Checks if the user exists in passwd */
-    if((fp=fopen(SAMBA_PASSWD,"r"))==NULL)
+    /* Puts the pdbedit userlist as:
+       /etc/gadmin-samba/gadmin_samba_users */
+    get_gadmin_samba_users();
+
+    /* Checks if the user exists */
+    if((fp=fopen(GADMIN_SAMBA_USERS,"r"))==NULL)
     {
 	/* Dont show anything */
     }
@@ -328,72 +332,76 @@ smbuser_locked(G_CONST_RETURN gchar *username)
     int prop_found = 0, account_locked = 0;
     char tempname[4096]="";
 
-    if((fp=fopen(SAMBA_PASSWD,"r"))==NULL)
+    get_gadmin_samba_users();
+
+    if((fp=fopen(GADMIN_SAMBA_USERS,"r"))==NULL)
     {
 	/* Dont show anything */
     }
-    else
-      {
-	    fseek(fp, 0, SEEK_END);
-	    conf_size = ftell(fp);
-	    rewind(fp);
-	    line = allocate(conf_size+1);
+    fseek(fp, 0, SEEK_END);
+    conf_size = ftell(fp);
+    rewind(fp);
+    line = allocate(conf_size+1);
 
-	    if( conf_size > 1 )
-	    while(fgets(line, conf_size, fp)!=NULL)
+    if( conf_size > 1 )
+    while(fgets(line, conf_size, fp)!=NULL)
+    {
+	for(x=0; line[x]!='\0'; x++)
+	{
+	    if( line[x]==':' )
 	    {
-		for(x=0; line[x]!='\0'; x++)
+		snprintf(tempname, 4000, "%s", line);
+		tempname[x]='\0';
+		if( ! strcmp(username, tempname) )
 		{
-		    if( line[x]==':' )
-		    {
-			snprintf(tempname, 4000, "%s", line);
-			tempname[x]='\0';
-			if( ! strcmp(username, tempname) )
-			{
-			    user_exists = 1;
-			    break;
-			}
-		    }
-		}
-		if( user_exists )
-		  break;
-	    }
-
-	    /* The samba user exists, see if its locked */
-	    if( user_exists )
-	    for(x=0; line[x]!='\0'; x++)
-	    {
-		/* Account properties are located between "[" and "]" */
-		if( line[x]=='[' )
-		{
-		    prop_found = 1;
+		    user_exists = 1;
 		    break;
 		}
 	    }
-	    
-	    if( user_exists && prop_found )
-	    for(x=x; line[x]!='\0'; x++)
-	    {
-		/* Read to the end of account properties "]" */
-		if( line[x]==']' )
-		    break;
+	}
+	if( user_exists )
+	  break;
+    }
 
-		/* Disabled accounts with previously set passwords
-		   can be enabled without setting a new one */
-		if( line[x]=='D' && ! strstr(line, "XXXXXXXXXXXX") )
-		    account_locked = 1;
+    /* The samba user exists, see if its locked */
+    if( user_exists )
+    for(x=0; line[x]!='\0'; x++)
+    {
+	/* Account properties are located between "[" and "]" */
+	if( line[x]=='[' )
+	{
+	    prop_found = 1;
+	    break;
+	}
+    }
+    if( user_exists && prop_found )
+    for(x=x; line[x]!='\0'; x++)
+    {
+	/* Read to the end of account properties "]" */
+	if( line[x]==']' )
+	  break;
 
-		/* Enabling accounts with no previous passwords requires new passwords */
-		if( line[x]=='D' && strstr(line, "XXXXXXXXXXXX") )
-		    account_locked = 2;
+	/* Disabled accounts with previously set passwords
+	   can be enabled without setting a new one */
+	if( line[x]=='D' )
+	{
+	    account_locked = 1;
+	    break;
+	}
 
-		/* Enabling accounts with NULL passwords requires new passwords */
-		if( line[x]=='N' )
-		    account_locked = 3;
-	    }
-	    free(line);
-	    fclose(fp);
-      }
+	/* Enabling accounts with no previous passwords requires new passwords */
+	if( strstr(line, "XXXXXXXXXXXX:[") )
+	{
+	    account_locked = 2;
+	    break;
+	}
+
+	/* Enabling accounts with NULL passwords requires new passwords */
+	if( line[x]=='N' )
+	    account_locked = 3;
+    }
+    free(line);
+    fclose(fp);
 
     return account_locked;
 }
@@ -412,37 +420,38 @@ user_exists(G_CONST_RETURN gchar *username)
     /* Checks if the user exists in passwd */
     if((fp=fopen(PASSWD_FILE,"r"))==NULL)
     {
-	/* Dont show anything */
+	printf("Unable to read file: [%s]\n", PASSWD_FILE);
+	return 0;
     }
     else
-      {
-	    fseek(fp, 0, SEEK_END);
-	    conf_size = ftell(fp);
-	    rewind(fp);
-	    line = allocate(conf_size);
+    {
+	fseek(fp, 0, SEEK_END);
+	conf_size = ftell(fp);
+	rewind(fp);
+	line = allocate(conf_size);
 
-	    if( conf_size > 1 )
-	    while(fgets(line, conf_size, fp)!=NULL)
+	if( conf_size > 1 )
+	while(fgets(line, conf_size, fp)!=NULL)
+	{
+	    for(x=0; line[x]; x++)
 	    {
-		for(x=0; line[x]; x++)
+		if( line[x]==':' )
 		{
-		    if( line[x]==':' )
+		    snprintf(tempname, 4000, "%s", line);
+		    tempname[x]='\0';
+		    if( strcmp(username, tempname) == 0 )
 		    {
-			snprintf(tempname, 4000, "%s", line);
-			tempname[x]='\0';
-			if( ! strcmp(username, tempname) )
-			{
-			    user_exists = 1;
-			    break;
-			}
+			user_exists = 1;
+			break;
 		    }
 		}
-		if( user_exists )
-		    break;
 	    }
-	    free(line);
-	    fclose(fp);
-      }
+	    if( user_exists )
+	      break;
+	}
+	free(line);
+	fclose(fp);
+    }
 
     /* Checks if the user exists in shadow */
     if((fp=fopen(SHADOW_FILE,"r"))==NULL)
@@ -450,35 +459,36 @@ user_exists(G_CONST_RETURN gchar *username)
 	/* Dont show anything */
     }
     else
-      {
-	    fseek(fp, 0, SEEK_END);
-	    conf_size = ftell(fp);
-	    rewind(fp);
-	    line = allocate(conf_size);
+    {
+	fseek(fp, 0, SEEK_END);
+	conf_size = ftell(fp);
+	rewind(fp);
+	line = allocate(conf_size);
 
-	    if( conf_size > 1 )
-	    while(fgets(line, conf_size, fp)!=NULL)
+	if( conf_size > 1 )
+	while(fgets(line, conf_size, fp)!=NULL)
+	{
+	    for(x=0; line[x]!='\0'; x++)
 	    {
-		for(x=0; line[x]!='\0'; x++)
+		if( line[x]==':' )
 		{
-		    if( line[x]==':' )
+		    snprintf(tempname, 4000, "%s", line);
+		    tempname[x]='\0';
+		    if( strcmp(username, tempname) == 0 ) 
+//		    if( strstr(username, tempname) 
+//		    && strlen(username) == strlen(tempname) )
 		    {
-			snprintf(tempname, 4000, "%s", line);
-			tempname[x]='\0';
-			if( strstr(username, tempname) 
-			&& strlen(username) == strlen(tempname) )
-			{
-			    user_exists = 1;
-			    break;
-			}
-		    }
-		    if( user_exists )
+			user_exists = 1;
 			break;
+		    }
 		}
+		if( user_exists )
+		  break;
 	    }
-	    free(line);
-	    fclose(fp);
-      }
+	}
+	free(line);
+	fclose(fp);
+    }
 
     return user_exists;
 }
@@ -515,7 +525,7 @@ group_exists(G_CONST_RETURN gchar *groupname)
 		    {
 			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
-			if( ! strcmp(groupname, tempname) )
+			if( strcmp(groupname, tempname) == 0 )
 			{
 			    group_exists = 1;
 			    break;
@@ -550,8 +560,9 @@ group_exists(G_CONST_RETURN gchar *groupname)
 		    {
 			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
-			if( strstr(groupname, tempname) 
-			&& strlen(groupname) == strlen(tempname) )
+			if( strcmp(groupname, tempname) == 0 ) 
+//			if( strstr(groupname, tempname) 
+//			&& strlen(groupname) == strlen(tempname) )
 			{
 			    group_exists = 1;
 			    break;
@@ -1282,19 +1293,3 @@ char *random_string(int len)
 
     return rnd_string;
 }
-
-
-/* Unused */
-void
-exec_ssl(char *command, char descr[128])
-{
-    FILE *fp;
-    if((fp=popen(command, "r"))==NULL)    
-    {
-	perror("popen");
-	printf("Error description: %s\n", descr);
-	printf("Error command: %s\n", command);
-	return;
-    }
-    pclose(fp);
-}
