@@ -52,11 +52,7 @@ int user_exists(G_CONST_RETURN gchar *username);
 
 int group_exists(G_CONST_RETURN gchar *username);
 
-
-// Remove, obsolete
 gchar *get_user_comment(gchar *user);
-void exec_ssl(char *command, char descr[128]);
-
 
 gchar *get_user_setting(gchar *user, gchar *what);
 
