@@ -32,6 +32,7 @@
 #include "show_info.h"
 #include "import_functions.h"
 #include "get_option_pos.h"
+#include "commands.h"
 #include "commented.h"
 #include "apply_share_settings.h"
 #include "populate_users.h"
@@ -201,19 +202,14 @@ void do_import(GtkTreeModel *model, GtkTreePath *path,
 	num_imported++;
 
 
-    /* If its user imports and this samba user doesnt exist, add it with an empty password */
+    /* If its user import and this samba user doesnt exist, add it with an empty password */
     if( ! smbuser_exists(name) && global_import_local && global_import_users )
     {
 	new_smbuser_added = 1;
 
-	cmd = g_strdup_printf("%s -a -n '%s'", SMBPASSWD_BINARY, name);
-        if((fp=popen(cmd, "w"))==NULL)
-          perror("popen");
-	else
-          pclose(fp);
-        
-        g_free(cmd);
-
+	if( add_null_password_samba_user(name) )
+	  new_smbuser_added = 1;
+	
 	/* Also create its /var/samba/profiles/UserName directory */
 	cmd = g_strdup_printf("mkdir -p %s%s/%s", LOCALSTATEDIR, "/samba/profiles", name);
         if((fp=popen(cmd, "w"))==NULL)
