@@ -52,11 +52,15 @@ void populate_maccts(struct w *widgets)
 
     gtk_list_store_clear(widgets->macct_store);
 
+    /* Puts the pdbedit userlist as:
+       /etc/gadmin-samba/gadmin_samba_users */
+    get_gadmin_samba_users();
+
     /* Populate the machine account list */
-    if((fp=fopen(SAMBA_PASSWD, "r"))==NULL)
+    if((fp=fopen(GADMIN_SAMBA_USERS, "r"))==NULL)
     {
 	/* Dont show a popup */
-	printf("Error opening: [%s] for listing machine accounts\n", SAMBA_PASSWD);
+	printf("Error opening: [%s] for listing machine accounts\n", GADMIN_SAMBA_USERS);
         return;
     }
     fseek(fp, 0, SEEK_END);
