@@ -342,17 +342,6 @@ void populate_server_settings(struct w *widgets)
             gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[18]), utf8);
 	}
 	else
-	if( cmplowercase(line, "smb passwd file") )
-	{
-	    opt_pos = get_option_pos(line);
-	    sprintf(new_buffer, "%s", &line[opt_pos]);
-	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
-	      new_buffer[strlen(new_buffer)-1]='\0';
-
-	    utf8 = g_locale_to_utf8(new_buffer, strlen(new_buffer), NULL, NULL, NULL);
-            gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[19]), utf8);
-	}
-	else
 	if( cmplowercase(line, "passwd program") )
 	{
 	    opt_pos = get_option_pos(line);
