@@ -32,9 +32,8 @@
 #include "chars_are_digits.h"
 #include "show_info.h"
 
-
 extern char global_user_name[1024];
-
+extern gulong account_disabled_toggled_signal;
 
 
 void populate_user_settings(struct w *widgets)
@@ -52,22 +51,32 @@ void populate_user_settings(struct w *widgets)
     }
     g_free(info);
 
-
     /* Get and insert the users settings */
     gchar *username = g_strdup_printf("%s", global_user_name);
     gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[0]), username);
 
-    /* Locked account checkbox and label modifications */
+
+    /* Locked account checkbox and label modifications, see if the account is locked. */
     locked = smbuser_locked(username);
+
+
+    /* Block the togglebuttons signal so it doesnt run its functions. */
+    /* This idiocy was added around 2005 ? ...
+       Whomever thought this was a great ideea for GTK+ should be shot on sight i think. */
+    g_signal_handler_block(GTK_WIDGET(widgets->user_set_checkbutton[0]), account_disabled_toggled_signal);
     
     if( locked && ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0])) )
         gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0]), TRUE);
     if( ! locked && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0])) )
         gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0]), FALSE);
 
-    if( locked == 1 || locked == 2 )
+    /* Unblock the togglebuttons signal */
+    g_signal_handler_unblock(GTK_WIDGET(widgets->user_set_checkbutton[0]), account_disabled_toggled_signal);
+
+
+    if( locked == 1 )
     {
-	/* Regular samba user account is locked */
+	/* Samba user account is locked but has a previous password. */
 	atext = g_strdup_printf(_("Account locked:"));
 	utf8 = g_locale_to_utf8(atext, strlen(atext), NULL, NULL, NULL);
 	gtk_label_set_text(GTK_LABEL(widgets->acclock_label), utf8);
@@ -77,6 +86,18 @@ void populate_user_settings(struct w *widgets)
 	  g_free(utf8);
     }
     else
+    if( locked == 2 )
+    {
+	/* Samba user account is locked but has no previous password. */
+	atext = g_strdup_printf(_("Missing password:"));
+	utf8 = g_locale_to_utf8(atext, strlen(atext), NULL, NULL, NULL);
+	gtk_label_set_text(GTK_LABEL(widgets->acclock_label), utf8);
+	if( atext!=NULL )
+	  g_free(atext);
+	if( utf8!=NULL )
+	  g_free(utf8);
+    }
+    else
     if( locked == 3 )
     {
 	/* A samba user with a Null password is considered locked but
