@@ -53,11 +53,17 @@ void populate_users(struct w *widgets)
 
     gtk_list_store_clear(widgets->user_store);
 
+
+    /* Puts the pdbedit userlist as:
+       /etc/gadmin-samba/gadmin_samba_users */
+    get_gadmin_samba_users();
+
+
     /* Populate the userlist */
-    if((fp=fopen(SAMBA_PASSWD, "r"))==NULL)
+    if((fp=fopen(GADMIN_SAMBA_USERS, "r"))==NULL)
     {
 	/* Dont show a popup */
-	printf("Error opening: [%s] for listing users\n", SAMBA_PASSWD);
+	printf("Error opening: [%s]\nwhen listing users.\n", GADMIN_SAMBA_USERS);
         return;
     }
     fseek(fp, 0, SEEK_END);
