@@ -227,9 +227,9 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, info);
     g_free(info);
 
-    info = g_strdup_printf("smb passwd file = %s/samba/smbpasswd\n", SYSCONFDIR);
-    strcat(buffer, info);
-    g_free(info);
+    /* Specify that tdbsam is used. */
+    strcat(buffer, "passdb backend = tdbsam\n");
+
 
     strcat(buffer, "passwd program = /usr/bin/passwd '%u'\n");
 
